pub struct Bindings {}Expand description
Auto-generated bindings for an instance a component which
implements the world bindings.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
Bindings::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
BindingsPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesBindingsPre::instantiateto create aBindings. -
If you’ve instantiated the instance yourself already then you can use
Bindings::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl Bindings
impl Bindings
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Bindings>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<Bindings>
Convenience wrapper around BindingsPre::new and
BindingsPre::instantiate.
Sourcepub fn new(store: impl AsContextMut, instance: &Instance) -> Result<Bindings>
pub fn new(store: impl AsContextMut, instance: &Instance) -> Result<Bindings>
Convenience wrapper around BindingsIndices::new and
BindingsIndices::load.
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Bindings>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Bindings>where
_T: Send,
Convenience wrapper around BindingsPre::new and
BindingsPre::instantiate_async.
pub fn add_to_linker<T, D>(
linker: &mut Linker<T>,
host_getter: fn(&mut T) -> D::Data<'_>,
) -> Result<()>where
D: HostWithStore + HostWithStore + HostWithStore + Send,
for<'a> D::Data<'a>: Host + Host + Host + Send,
T: 'static + Send,