pub trait HostError {
// Required methods
fn to_debug_string(&mut self, self_: Resource<Error>) -> Result<String>;
fn drop(&mut self, rep: Resource<Error>) -> Result<()>;
}Required Methods
Sourcefn to_debug_string(&mut self, self_: Resource<Error>) -> Result<String>
fn to_debug_string(&mut self, self_: Resource<Error>) -> Result<String>
Returns a string that is suitable to assist humans in debugging this error.
WARNING: The returned string should not be consumed mechanically! It may change across platforms, hosts, or other implementation details. Parsing this string is a major platform-compatibility hazard.
fn drop(&mut self, rep: Resource<Error>) -> Result<()>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl HostError for ResourceTable
impl HostError for ResourceTable
Sourceimpl<_T: HostError + ?Sized> HostError for &mut _T
impl<_T: HostError + ?Sized> HostError for &mut _T
Sourcefn to_debug_string(&mut self, self_: Resource<Error>) -> Result<String>
fn to_debug_string(&mut self, self_: Resource<Error>) -> Result<String>
Returns a string that is suitable to assist humans in debugging this error.
WARNING: The returned string should not be consumed mechanically! It may change across platforms, hosts, or other implementation details. Parsing this string is a major platform-compatibility hazard.